@@ -10,7 +10,7 @@
  *
  * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
  * Copyright (c) 2007 Toni Spets
- * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2021 Brenden Matthews, Philip Kovacs, et. al.
  *	(see AUTHORS)
  * All rights reserved.
  *
@@ -93,10 +93,10 @@ void get_ibm_acpi_fan(struct text_object *obj, char *p,
       if (sscanf(line, "speed: %u", &speed)) { break; }
     }
   } else {
-    CRIT_ERR(nullptr, NULL,
-             "can't open '%s': %s\nYou are not using the IBM ACPI. Remove "
-             "ibm* from your " PACKAGE_NAME " config file.",
-             fan, strerror(errno));
+    CRIT_ERR(
+        "can't open '%s': %s\nYou are not using the IBM ACPI. Remove "
+        "ibm* from your " PACKAGE_NAME " config file.",
+        fan, strerror(errno));
   }
 
   fclose(fp);
@@ -144,10 +144,10 @@ int get_ibm_acpi_temps(void) {
       }
     }
   } else {
-    CRIT_ERR(nullptr, NULL,
-             "can't open '%s': %s\nYou are not using the IBM ACPI. Remove "
-             "ibm* from your " PACKAGE_NAME " config file.",
-             thermal, strerror(errno));
+    CRIT_ERR(
+        "can't open '%s': %s\nYou are not using the IBM ACPI. Remove "
+        "ibm* from your " PACKAGE_NAME " config file.",
+        thermal, strerror(errno));
   }
 
   fclose(fp);
@@ -191,10 +191,10 @@ void get_ibm_acpi_volume(struct text_object *obj, char *p,
       if (sscanf(line, "mute: %s", mute)) { break; }
     }
   } else {
-    CRIT_ERR(nullptr, NULL,
-             "can't open '%s': %s\nYou are not using the IBM ACPI. Remove "
-             "ibm* from your " PACKAGE_NAME " config file.",
-             volume, strerror(errno));
+    CRIT_ERR(
+        "can't open '%s': %s\nYou are not using the IBM ACPI. Remove "
+        "ibm* from your " PACKAGE_NAME " config file.",
+        volume, strerror(errno));
   }
 
   fclose(fp);
@@ -235,10 +235,10 @@ void get_ibm_acpi_brightness(struct text_object *obj, char *p,
       if (sscanf(line, "level: %u", &brightness)) { break; }
     }
   } else {
-    CRIT_ERR(nullptr, NULL,
-             "can't open '%s': %s\nYou are not using the IBM ACPI. Remove "
-             "ibm* from your " PACKAGE_NAME " config file.",
-             filename, strerror(errno));
+    CRIT_ERR(
+        "can't open '%s': %s\nYou are not using the IBM ACPI. Remove "
+        "ibm* from your " PACKAGE_NAME " config file.",
+        filename, strerror(errno));
   }
 
   fclose(fp);
@@ -275,10 +275,10 @@ void get_ibm_acpi_thinklight(struct text_object *obj, char *p,
       if (sscanf(line, "status: %s", thinklight)) { break; }
     }
   } else {
-    CRIT_ERR(nullptr, NULL,
-             "can't open '%s': %s\nYou are not using the IBM "
-             "ACPI. Remove ibm* from your " PACKAGE_NAME " config file.",
-             filename, strerror(errno));
+    CRIT_ERR(
+        "can't open '%s': %s\nYou are not using the IBM "
+        "ACPI. Remove ibm* from your " PACKAGE_NAME " config file.",
+        filename, strerror(errno));
   }
 
   fclose(fp);
