@@ -903,6 +903,10 @@ void determine_longstat_file(void) {
   FILE *stat_fp;
   static int reported = 0;
   char buf[MAX_PROCSTAT_LINELEN + 1];
+  static int stat_initialized = 0;
+
+  /* only execute once */
+  if (stat_initialized) return;
 
   if (!(stat_fp = open_file("/proc/stat", &reported))) return;
   while (!feof(stat_fp) &&
@@ -913,6 +917,7 @@ void determine_longstat_file(void) {
     }
   }
   fclose(stat_fp);
+  stat_initialized = 1;
 }
 
 void get_cpu_count(void) {
@@ -1000,6 +1005,7 @@ int update_stat(void) {
   }
 
   if (!stat_template) {
+    determine_longstat_file();
     stat_template =
         KFLAG_ISSET(KFLAG_IS_LONGSTAT) ? TMPL_LONGSTAT : TMPL_SHORTSTAT;
   }
@@ -1213,7 +1219,11 @@ static void get_dev_path(const char *dir, const char *dev, char *out_buf) {
 
     snprintf(path, 512, "%s%s/name", dir, namelist[i]->d_name);
     name_fd = open(path, O_RDONLY);
-    if (name_fd < 0) continue;
+    if (name_fd < 0) {
+      snprintf(path, 512, "%s%s/device/name", dir, namelist[i]->d_name);
+      name_fd = open(path, O_RDONLY);
+      if (name_fd < 0) continue;
+    }
     size = read(name_fd, name, strlen(dev));
     if (size < strlen(dev)) {
       close(name_fd);
