@@ -61,8 +61,7 @@ class obj_create_error : public std::runtime_error {
   obj_create_error(const std::string &msg) : std::runtime_error(msg) {}
 };
 
-void clean_up(void *memtofree1, void *memtofree2);
-void clean_up_without_threads(void *memtofree1, void *memtofree2);
+void clean_up(void);
 
 template <typename... Args>
 inline void gettextize_format(const char *format, Args &&...args) {
@@ -80,21 +79,21 @@ void NORM_ERR(const char *format, Args &&...args) {
   fputs("\n", stderr);
 }
 
-/* critical error */
+/* critical error with additional cleanup */
 template <typename... Args>
-inline void CRIT_ERR(void *memtofree1, void *memtofree2, const char *format,
-                     Args &&...args) {
+inline void CRIT_ERR_FREE(void *memtofree1, void *memtofree2,
+                          const char *format, Args &&...args) {
   NORM_ERR(format, args...);
-  clean_up(memtofree1, memtofree2);
+  free(memtofree1);
+  free(memtofree2);
+  clean_up();
   exit(EXIT_FAILURE);
 }
 
+/* critical error */
 template <typename... Args>
-inline void THREAD_CRIT_ERR(void *memtofree1, void *memtofree2,
-                            const char *format, Args &&...args) {
-  NORM_ERR(format, args...);
-  clean_up_without_threads(memtofree1, memtofree2);
-  return;
+inline void CRIT_ERR(const char *format, Args &&...args) {
+  CRIT_ERR_FREE(nullptr, nullptr, format, args...);
 }
 
 namespace conky {
