@@ -35,6 +35,9 @@
 
 void print_cat(struct text_object *, char *, unsigned int);
 void print_catp(struct text_object *, char *, unsigned int);
-void print_cap(struct text_object *, char *, unsigned int);
+void print_startcase(struct text_object *, char *, unsigned int);
+void print_lowercase(struct text_object *, char *, unsigned int);
+void print_uppercase(struct text_object *, char *, unsigned int);
+void strip_trailing_whitespace(struct text_object *, char *, unsigned int);
 long long apply_base_multiplier(const char *, long long int);
 #endif /* _MISC_H */
